# Generated by Django 2.2.16 on 2021-03-02 11:41
import logging

import django.contrib.gis.db.models.fields
from django.contrib.gis.geos import Polygon

from django.db import migrations

logger = logging.getLogger(__name__)


def populate_ll_polygon(apps, schema_editor):
    ResourceBase = apps.get_model('base', 'ResourceBase')
    for res in ResourceBase.objects.all():
        try:
            bbox = res.bbox_polygon
            srid = None
            srid = int(res.srid.split(':')[1]) if res.srid else 4326
            # pre-catch well known data problems
            if srid == 404000:
                logger.warning(f"Skipping resource ID:{res.id} '{res.title}' SRID:{res.srid} ({srid})")
                continue

            if bbox and srid:
                    bbox = bbox.clone()
                    bbox.srid = srid
                    bbox.transform(4326)
                    res.ll_bbox_polygon = bbox
                    res.save()
        except Exception as e:
            logger.warning(f"Error while transforming resource ID:{res.id} '{res.title}' SRID:{res.srid} ({srid}): {e}", exc_info=e)
            raise e

class Migration(migrations.Migration):

    dependencies = [
        ('base', '0055_auto_20210302_1109'),
    ]

    operations = [
        migrations.AddField(
            model_name='resourcebase',
            name='ll_bbox_polygon',
            field=django.contrib.gis.db.models.fields.PolygonField(blank=True, null=True, srid=4326),
        ),
        migrations.RunPython(populate_ll_polygon, migrations.RunPython.noop),
    ]
